# coding: utf-8

import os
import webbrowser

import Tkinter as tk
import ttk
import tkFont

from tionix_vdi_client.i18n import ugettext as _
from tionix_vdi_client.settings import RESOURCES_DIR

from tionix_vdi_client.helpers import Colors


class SaveParametersCheckBox(tk.Checkbutton):

    def __init__(self, master, row, column, default_value=True):
        self.value = tk.BooleanVar(value=default_value)
        self.config = {
            'text': ' ' + _('Remember'),
            'variable': self.value,
            'activebackground': Colors.GREY,
        }
        tk.Checkbutton.__init__(self, master, cnf=self.config,
                                variable=self.value)
        self.grid(row=row, column=column, sticky=tk.E, padx=65)


class LinkLabel(tk.Label):

    def bind_link(self, link, underline=None):
        """
        Binds link to the element. Adds color, text underline and
        cursor change on hover effect.
        :param link: Link to webpage or valid path to local file.
        :param underline: text underline
        :return: None
        """
        def enter(event):
            self.configure(cursor="hand2")

        def leave(event):
            self.configure(cursor="")

        def click(event):
            webbrowser.open_new(link)

        self.bind("<Enter>", enter)
        self.bind("<Leave>", leave)
        self.bind("<Button-1>", click)
        self.configure(fg=Colors.DARK_BLUE, underline=underline)


class CustomEntry(ttk.Entry):
    def __init__(self, *args, **kwargs):
        ttk.Entry.__init__(self, *args, **kwargs)
        self._rc_menu_install()
        # overwrite default class binding so we don't need to return "break"
        self.bind_class("Entry", "<Control-a>", self.event_select_all)
        self.bind("<Button-3><ButtonRelease-3>", self.show_menu)

    def _rc_menu_install(self):
        self.menu = tk.Menu(self, tearoff=0)
        self.menu.add_command(label="Cut")
        self.menu.add_command(label="Copy")
        self.menu.add_command(label="Paste")

        self.menu.entryconfigure(
            "Cut",
            command=lambda: self.focus_force() or self.event_generate(
                "<<Cut>>"))
        self.menu.entryconfigure(
            "Copy",
            command=lambda: self.focus_force() or self.event_generate(
                "<<Copy>>"))
        self.menu.entryconfigure(
            "Paste",
            command=lambda: self.focus_force() or self.event_generate(
                "<<Paste>>"))

    def event_select_all(self, *args):
        self.focus_force()
        self.selection_range(0, tk.END)

    def show_menu(self, e):
        self.tk.call("tk_popup", self.menu, e.x_root, e.y_root)


class HelpLabel(object):

    def __init__(self, master, row, col, link=''):

        self.help_msg = _(u'Help')

        # default font doesn't have proper underline
        # so we need to configure it
        self.font = tkFont.Font(master, size=10)
        self.font.configure(underline=1)

        self.help_icon = tk.PhotoImage(
            file=os.path.join(RESOURCES_DIR, 'help.gif'))

        self.help_label = LinkLabel(master)
        self.help_label.configure(text=self.help_msg, underline=1,
                                  font=self.font)
        self.help_label.grid(row=row, column=col, padx=20, sticky=tk.E)
        self.help_label.bind_link(link, underline=True)

        # Calc padding between text and icon
        padding = len(self.help_msg) * 13
        self.help_icon_label = LinkLabel(master)
        self.help_icon_label.configure(image=self.help_icon,
                                       width=20, height=20)
        self.help_icon_label.grid(row=1, column=2, sticky=tk.E, padx=padding)
        self.help_icon_label.bind_link(link)
