# coding: utf-8
import logging
import platform
import sys
from StringIO import StringIO
from contextlib import contextmanager


class Colors(object):
    GREY = '#d9d9d9'
    DARK_BLUE = "#23527c"


class Localization(object):
    EN = 'en'
    RU = 'ru'

    RU_CODE = 'ru_RU'
    EN_US_CODE = 'en_US'

    locales_dict = {
        RU: RU_CODE,
        EN: EN_US_CODE,
    }

    locales_translate = {
        RU: u'Русский',
        EN: u'English',
    }


def get_key_by_value(dict_obj, val_param):
    for key, value in dict_obj.iteritems():
        if value == val_param:
            return key


def get_win_info():
    return u'{system} {version}'.format(
        system=platform.system(),
        version=platform.release())


def get_linux_info():
    distname, version, _id = platform.linux_distribution()
    return u'{distname} {version}'.format(
        distname=distname,
        version=version)


def get_os_version():
    """Get operating system version"""
    system = platform.system()
    info_getters = {
        u'Linux': get_linux_info,
        u'Windows': get_win_info,
    }
    info_getter = info_getters.get(system, platform.platform)
    return info_getter()


def get_win_os_bitness():
    """Get Windows bitness. For Linux returns empty string."""
    bitness = ''
    os_bitness, os_name = platform.architecture()
    if 'windows' in os_name.lower():
        if '64' in os_bitness:
            bitness = 'x64'
        else:
            bitness = 'x32'
    return bitness


@contextmanager
def suppress_stdout():
    new_stdout = StringIO()
    old_stdout = sys.stdout
    old_stderr = sys.stderr
    logging.disable(logging.ERROR)
    try:
        sys.stdout = new_stdout
        sys.stderr = new_stdout
        yield
    finally:
        sys.stdout = old_stdout
        sys.stderr = old_stderr
        logging.disable(logging.NOTSET)
