# coding: utf-8

import re
all_ips_re = re.compile(r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}')

valid_ip_re = re.compile(
    r'(25[0-5]|2[0-4]\d|[0-1]?\d?\d)(\.(25[0-5]|2[0-4]\d|[0-1]?\d?\d)){3}')

cookie_re = re.compile(r'^WGSESSION=*==;')
form_teg_re = re.compile(r'action\s*=[^>]*"')


def get_valid_url(url=None):
    url = url or ''
    schema = 'http://'
    slash = '/'
    path = '/vdi/api'
    # check prefix
    url = url if url.startswith(schema) else schema + url.strip(slash)
    url = url if path in url or url == schema else url + path

    # check slash at the end
    srv = url if url.endswith(slash) else url + slash
    return srv


def split_ip_address(ip_string):
    """Returns all valid ip addresses from given string"""
    ips = re.findall(all_ips_re, ip_string)

    valid_ips = [x.group() for x in
                 filter(bool, [re.match(valid_ip_re, ip) for ip in ips])]
    return valid_ips


def split_cookie(raw_cookie):
    # cookie = raw_cookie.lstrip('WGSESSION=')
    cookie = raw_cookie.split('; ')
    if len(cookie) >= 1:
        cookie = cookie[0]

    return cookie


def split_login_url(text):
    form_tags = re.search(form_teg_re, text)
    url = ''
    if form_tags:
        try:
            _action, url = form_tags.group().split('=')
        except IndexError:
            url = ''

        url = url.strip("'\"")

    return url


def run_test():
    def do_test_over_expected_results(test_strings, test_fn):
        """Make test over input data with some function and expect result"""
        for test_str, valid_result in test_strings:
            res = test_fn(test_str)
            assert res == valid_result, (
                "EXPECTED: %s; GOT: %s " % (valid_result, res))

    def test_get_valid_url():
        fn_name = 'test_get_valid_url'

        assert get_valid_url() == "http://", fn_name
        assert get_valid_url("") == "http://", fn_name
        assert get_valid_url("/") == "http://", fn_name
        assert get_valid_url("/url") == "http://url/vdi/api/", fn_name
        assert get_valid_url("url/") == "http://url/vdi/api/", fn_name
        assert get_valid_url("http://") == "http://", fn_name
        assert get_valid_url("http://url") == "http://url/vdi/api/", fn_name

    def test_split_ip_address():
        test_strings = [
            ('<asdf10.10.10.10> asd</>10.10.101asdas',
             ['10.10.10.10']),
            ('<asdf256.10.10.10> asd</>10.10.11.10<asdas>',
             ['10.10.11.10']),
            ('<asdf10.10.10.10> asd</>50.40.10.1asdas',
             ['10.10.10.10', '50.40.10.1']),
            ("""<HEAD></HEAD><a href="http://217.198.8.13:6080/vnc_auto.html?
            token=f7f4fb50-120d-4939-849e-db596a00d465">10.10.54.35</a>:""",
             ['217.198.8.13', '10.10.54.35']),

        ]
        do_test_over_expected_results(test_strings, split_ip_address)

    def test_split_login_url():
        txt = """<!DOCTYPE html>
            <!-- /<html>-->
            <head><LINK REL="stylesheet" TYPE="text/css" HREF="vdi.css">
            <title> Форма авторизации </title>
            <meta charset="UTF-8">
            <block><form id="loginForm" form action="auth/vdi.cgi" method=POST>
            <div style="margin: 20px;"><myh1>TIONIX VDI</myh1></div>
            <div><myh2>Авторизуйтесь в системе</myh2></div>
            <div class="field"><label>Логин:</label>
            <div class="input"><input type=text name="user"></div>
            </div><div class="field"><label> Пароль:</label>
            <div class="input"> <input type=password name="password"></div">
            </div><div class="field"><label> Домен:</label>
            <div class="input"> <input type=text name="project"></div">
            </div><input id="but2" input type=submit value="Войти"></div>
            </form></block></head></html>"""
        result = "auth/vdi.cgi"
        assert split_login_url(txt) == result, "test_split_login_url"

    test_split_ip_address()
    test_get_valid_url()
    test_split_login_url()

if __name__ == '__main__':
    run_test()
