# coding: utf-8

import unittest

import ConfigParser as configparser

from tionix_vdi_client.i18n import ugettext as _
from tionix_vdi_client.settings import ConfigSettings, SessionSettings


class ConfigFilesTest(unittest.TestCase):
    msg_save_failed = _(u"Failed save to {0} file. "
                        u"Please check write permissions of {1}.")
    config_transl = _(u'config')
    session_transl = _(u'session')

    def test_config_file_read_save(self):
        """Checks write permissions for config file.

        :lang:ru Проверяет наличие прав на запись в файл конфигурации.
        """
        conf_parser = configparser.ConfigParser()
        conf_settings_location = ConfigSettings()._default_config_name

        msg_failed_save_config = self.msg_save_failed.format(
            self.config_transl, conf_settings_location)

        try:
            conf_parser.read(conf_settings_location)
        except (configparser.ParsingError,
                configparser.MissingSectionHeaderError):
            self.fail(_(u"Failed to parse config file."))

        test_cloud = 'test.loc'

        config_file = ConfigSettings()
        config_file.read(reread=True)

        orig_cloud = config_file.cloud
        config_file.cloud = test_cloud
        config_file.save()

        config_file.read(reread=True)

        self.assertNotEquals(orig_cloud, config_file.cloud,
                             msg=_(msg_failed_save_config))

        config_file.cloud = orig_cloud
        config_file.save()

        config_file.read(reread=True)

        self.assertEquals(orig_cloud, config_file.cloud,
                          msg=_(msg_failed_save_config))

    def test_session_file_read_save(self):
        """Checks write permissions for config file.

        :lang:ru Проверяет наличие прав на запись в файл сессии.
        """
        session_file_location = SessionSettings()._session_file_name
        msg_failed_save_session = self.msg_save_failed.format(
            self.session_transl, session_file_location)

        test_username = 'tester'

        sessions_settings = SessionSettings()
        try:
            sessions_settings.read()
        except (configparser.ParsingError,
                configparser.MissingSectionHeaderError):
            self.fail(_(u"Failed to parse session file."))

        orig_user = sessions_settings.user
        sessions_settings.user = test_username
        sessions_settings.save()

        sessions_settings.read()

        self.assertEqual(test_username, sessions_settings.user,
                         msg=_(msg_failed_save_session))

        sessions_settings.user = orig_user
        sessions_settings.save()

        sessions_settings.read()

        self.assertEqual(orig_user, sessions_settings.user,
                         msg=_(msg_failed_save_session))
