# coding: utf-8

import unittest

import requests

from tionix_vdi_client import exceptions as vdi_exceptions
from tionix_vdi_client.i18n import ugettext as _
from tionix_vdi_client.settings import ConfigSettings, SessionSettings
from tionix_vdi_client.vdi_connect import get_connection_params, get_vm_ip


class VDIConnectionTest(unittest.TestCase):
    def setUp(self):
        self.session_settings = SessionSettings()
        self.session_settings.read()

        self.config_settings = ConfigSettings()
        self.config_settings.read(reread=True)

    def test_get_vdi_instance_ip(self):
        """Checks that VDIclient can obtain instance IP address using
         saved session credentials.

        :lang:ru Проверяет что VDIclient может получить IP адрес ВМ,
         используя сохранённые данные из файла сессии.
        """
        try:
            conn_params = get_connection_params(self.session_settings,
                                                self.config_settings)
        except vdi_exceptions.MissingParameterException as err:
            self.skipTest(
                _(u"Can't check connection. One or more connection "
                  u"parameters are missing: {0}").format(err.message)
            )
        except Exception as err:
            self.fail(_(u"Failed to obtain connection parameters. "
                        u"Unexpected error occurred: "
                        u"{reason}.").format(err.message))
        else:
            try:
                get_vm_ip(**conn_params)
            except (vdi_exceptions.ApplicationConnectionError,
                    requests.exceptions.ConnectionError,
                    requests.exceptions.InvalidURL):
                cloud_ip = self.config_settings.cloud
                self.fail(_(u"Failed to connect to "
                            u"server {ip}.").format(ip=cloud_ip))

            except (vdi_exceptions.VDIServerBadCredentialsError,
                    vdi_exceptions.VDIServerBadConnectionParamsError) as err:
                self.fail(_(u"Failed to obtain VDI instance IP address. "
                            u"{reason}").format(reason=err.message))

            except vdi_exceptions.VDIServerResponseError as err:
                self.skipTest(err.message)

            except Exception as err:
                self.fail(_(u"Failed to obtain VDI instance IP address. "
                            u"Unexpected error occurred: "
                            u"{reason}.").format(err.message))
